==> open-xchange-usm_7.4.0.orig.tar.bz2: open-xchange-usm-7.4.0/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/cache/MemorySyncStateCacheProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.session.impl.cache;

import com.openexchange.usm.api.cache.SyncStateCache;
import com.openexchange.usm.api.cache.SyncStateCacheProvider;
import com.openexchange.usm.api.session.CompleteSessionID;
import com.openexchange.usm.session.impl.SessionImpl;
import com.openexchange.usm.session.impl.SessionManagerImpl;
import com.openexchange.usm.session.impl.SessionReference;

/**
 * {@link MemorySyncStateCacheProvider} Default provider for the SyncState cache, uses simple in-memory storage, creates 1 simple cache per USM session.
 * 
 * @author <a href="mailto:afe@microdoc.de">Alexander Feess</a>
 */
public class MemorySyncStateCacheProvider implements SyncStateCacheProvider {

    private final SessionManagerImpl _sessionManager;

    public MemorySyncStateCacheProvider(SessionManagerImpl sessionManager) {
        _sessionManager = sessionManager;
    }

    public SyncStateCache getCache(CompleteSessionID session) {
        return new MemorySyncStateCache();
    }

    public void freeCache(CompleteSessionID session) {
        // Nothing to do, cache will be garbage collected
    }

    public void removeCacheCompletely(CompleteSessionID session) {
        // Nothing to do, cache will be garbage collected
    }

    public int getSyncStateCount() {
        int count = 0;
        for (SessionReference reference : _sessionManager.getSessionStorage().getSessionReferences()) {
            SessionImpl session = reference.poll();
            if (session != null) {
                SyncStateCache syncStateCache = session.getDataObjectCache().getSyncStateCache();
                if (syncStateCache instanceof MemorySyncStateCache)
                    count += ((MemorySyncStateCache) syncStateCache).getSyncStateCount();
            }
        }
        return count;
    }

    public int removeUnusedSyncStates(long limit) {
        int count = 0;
        for (SessionReference reference : _sessionManager.getSessionStorage().getSessionReferences()) {
            SessionImpl session = reference.poll();
            if (session != null) {
                SyncStateCache syncStateCache = session.getDataObjectCache().getSyncStateCache();
                if (syncStateCache instanceof MemorySyncStateCache)
                    count += ((MemorySyncStateCache) syncStateCache).removeUnusedSyncStates(limit);
            }
        }
        return count;
    }
}

==> open-xchange-usm_7.4.2.orig.tar.bz2: open-xchange-usm-7.4.2/com.openexchange.usm.session.impl/src/com/openexchange/usm/session/impl/cache/MemorySyncStateCacheProvider.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.usm.session.impl.cache;

import com.openexchange.usm.api.cache.SyncStateCache;
import com.openexchange.usm.api.cache.SyncStateCacheProvider;
import com.openexchange.usm.api.session.CompleteSessionID;
import com.openexchange.usm.session.impl.SessionImpl;
import com.openexchange.usm.session.impl.SessionManagerImpl;
import com.openexchange.usm.session.impl.SessionReference;

/**
 * {@link MemorySyncStateCacheProvider} Default provider for the SyncState cache, uses simple in-memory storage, creates 1 simple cache per USM session.
 * 
 * @author <a href="mailto:afe@microdoc.de">Alexander Feess</a>
 */
public class MemorySyncStateCacheProvider implements SyncStateCacheProvider {

    private final SessionManagerImpl _sessionManager;

    public MemorySyncStateCacheProvider(SessionManagerImpl sessionManager) {
        _sessionManager = sessionManager;
    }

    public SyncStateCache getCache(CompleteSessionID session) {
        return new MemorySyncStateCache(_sessionManager.getMaxSyncStatesInDB());
    }

    public void freeCache(CompleteSessionID session) {
        // Nothing to do, cache will be garbage collected
    }

    public void removeCacheCompletely(CompleteSessionID session) {
        // Nothing to do, cache will be garbage collected
    }

    public int getSyncStateCount() {
        int count = 0;
        for (SessionReference reference : _sessionManager.getSessionStorage().getSessionReferences()) {
            SessionImpl session = reference.poll();
            if (session != null) {
                SyncStateCache syncStateCache = session.getDataObjectCache().getSyncStateCache();
                if (syncStateCache instanceof MemorySyncStateCache)
                    count += ((MemorySyncStateCache) syncStateCache).getSyncStateCount();
            }
        }
        return count;
    }

    public int removeUnusedSyncStates(long limit) {
        int count = 0;
        for (SessionReference reference : _sessionManager.getSessionStorage().getSessionReferences()) {
            SessionImpl session = reference.poll();
            if (session != null) {
                SyncStateCache syncStateCache = session.getDataObjectCache().getSyncStateCache();
                if (syncStateCache instanceof MemorySyncStateCache)
                    count += ((MemorySyncStateCache) syncStateCache).removeUnusedSyncStates(limit);
            }
        }
        return count;
    }
}
